@@ -9,6 +9,9 @@ use crate::Permissions;
 use diesel_migrations::embed_migrations;
 
 embed_migrations!("migrations/");
+pub mod migrations {
+    pub use super::embedded_migrations::*;
+}
 
 /// This is the diesel version of a user, meaning it is not designed to be
 /// worked with but rathre used as an intermediary between the databases
